import os
from random import randrange


def fullname_en(sex='r'):
    if sex == 'male' or sex == 'm':
        sex = 0
    elif sex == 'female' or sex == 'f':
        sex = 1
    elif sex == 'random' or sex == 'r':
        sex = randrange(2)
    else:
        return None

    path = os.path.dirname(__file__)
    file = ['male_en.txt', 'female_en.txt']
    suffix1 = [
        '', '', '', '', '', '', '', '', '', '',
        'pour',
        'zadeh',
        'far',
        'fard',
        'an',
        'kia',
        'rad',
        'zand',
        'khah',
        'nia'
    ]
    suffix2 = [
        'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i',
        'pour',
        'zadeh',
        'far',
        'fard',
        'khani',
        'vand',
        'lou',
        'nia'
    ]

    def first(sex):
        f = open(path + '/data/' + file[sex], 'r', encoding='utf8')
        names = f.read().split('\n')
        first = names[randrange(len(names))]
        return first

    def last():
        f = open(path + '/data/' + file[0], 'r', encoding='utf8')
        names = f.read().split('\n')
        last = names[randrange(len(names))]
        if last[1:] == 'ostafa' or last[1:] == 'ousa' or last[1:] == 'ahya':
            last += 'vi'
        elif last[1:] == 'orteza':
            last = last.replace('ez', 'az') + 'vi'
        elif last[1:] == 'hosro':
            last = last.replace('ro', 'ravi')
        elif last[-1] == 'a' or last[-1] == 'o' or last[-1] == 'u':
            last += 'ei'
        elif last[-1] == 'i':
            pass
        else:
            last += ['i', ''][randrange(2)]
        if len(last) > 10 and last[-1] == 'i':
            last += ''
        elif len(last) > 10 and last[-1] != 'i':
            last += 'i'
        elif last[-1] == 'i':
            last += suffix1[randrange(len(suffix1))]
        else:
            last += suffix2[randrange(len(suffix2))]
        return last

    return first(sex) + ' ' + last()


def fullname_fa(sex='r'):
    if sex == 'male' or sex == 'm':
        sex = 0
    elif sex == 'female' or sex == 'f':
        sex = 1
    elif sex == 'random' or sex == 'r':
        sex = randrange(2)
    else:
        return None

    path = os.path.dirname(__file__)
    file = ['male_fa.txt', 'female_fa.txt']
    suffix1 = [
        '', '', '', '', '', '', '', '', '', '',
        ' پور',
        ' زاده',
        ' فر',
        ' فرد',
        'ان',
        ' کیا',
        ' راد',
        ' زند',
        ' خواه',
        ' نیا'
    ]
    suffix2 = [
        'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی',
        ' پور',
        ' زاده',
        ' فر',
        ' فرد',
        ' خانی',
        ' وند',
        ' لو',
        ' نیا'
    ]

    def first(sex):
        f = open(path + '/data/' + file[sex], 'r', encoding='utf8')
        names = f.read().split('\n')
        first = names[randrange(len(names))]
        return first

    def last():
        f = open(path + '/data/' + file[0], 'r', encoding='utf8')
        names = f.read().split('\n')
        last = names[randrange(len(names))]
        if last == 'مرتضی' or last == 'مصطفی' or last == 'موسی':
            last = last.replace('ی', 'وی')
        elif last == 'یحیی':
            last = last.replace('یی', 'یوی')
        elif last == 'خسرو':
            pass
        elif last[-1] == 'ا' or last[-1] == 'و':
            last += 'ئی'
        elif last[-1] == 'ی':
            pass
        else:
            last += ['ی', ''][randrange(2)]
        if last[-1] == 'ی':
            last += suffix1[randrange(len(suffix1))]
        else:
            last += suffix2[randrange(len(suffix2))]
        return last

    return first(sex) + ' ' + last()



from setuptools import setup

with open('./README.md', 'r') as f:
    readme = f.read()

setup(
    name='persian-names',
    version='1.2.3',
    packages=['persian_names'],
    include_package_data=True,
    data_files=[('', [
        'persian_names/data/female_en.txt',
        'persian_names/data/female_fa.txt',
        'persian_names/data/male_en.txt',
        'persian_names/data/male_fa.txt'
    ])],
    url='https://github.com/armanyazdi/persian-names',
    license='MIT',
    author='Arman Yazdi',
    description='A Python library for generating random Persian (Farsi) names.',
    long_description=readme,
    long_description_content_type='text/markdown',
    keywords='persian names, farsi names, iranian names, name generator',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Natural Language :: Persian',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Localization'
    ],
    project_urls={
        'Source': 'https://github.com/armanyazdi/persian-names',
        'Documentation': 'https://pypi.org/project/persian-names',
    },
)
